# Balegram - Bale Module

## Usages
#
### Work with `Message` Object

+ ![Message Worker](https://github.com/AshyX-Dev/balegram/blob/main/screenshots/work_message.png)

### Answer Callback

+ ![Answer Callback](https://github.com/AshyX-Dev/balegram/blob/main/screenshots/answer_callback.png)
